﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Collections;
using OrderSystemDAL;

namespace OrderSystemBLL
{
    public class UserAccountEO
    {
        public int Id { get; set; }
        public string FirstName { get; set; }
        public string LastName { get; set; }
        public DateTime InsertDate { get; set; }
        public DateTime UpdateDate { get; set; }

        public string FullName
        {
            get
            {
                return LastName + ", " + FirstName;
            }
        }

        public bool Save(ref ArrayList validationErrors)
        {
            ValidateSave(ref validationErrors);

            if (validationErrors.Count == 0)
            {
                if (Id == 0)
                {
                    Id = UserAccountsData.Insert(FirstName, LastName, DateTime.Now);
                }
                else
                {
                    UserAccountsData.Update(Id, FirstName, LastName, DateTime.Now);
                }
                return true;
            }
            else
            {
                return false;
            }
        }

        private void ValidateSave(ref ArrayList validationErrors)
        {
            if (FirstName.Trim() == "")
            {
                validationErrors.Add("The First Name is required.");
            }

            if (LastName.Trim() == "")
            {
                validationErrors.Add("The Last Name is required.");
            }
        }

        public void Delete(ref ArrayList validationErrors)
        {
            ValidateDelete(ref validationErrors);

            if (validationErrors.Count == 0)
            {
                UserAccountsData.Delete(Id);
            }
        }

        private void ValidateDelete(ref ArrayList validationErrors)
        {
            //Check for referential integrity.
        }

        public bool Select(int id)
        {
            UserAccount userAccount = UserAccountsData.SelectById(id);

            if (userAccount != null)
            {
                MapData(userAccount);
                return true;
            }
            else
            {
                return false;
            }
        }

        internal void MapData(UserAccount userAccount)
        {
            Id = userAccount.Id;
            FirstName = userAccount.FirstName;
            LastName = userAccount.LastName;
            InsertDate = userAccount.AuditFields_InsertDate;
            UpdateDate = userAccount.AuditFields_UpdateDate;
        }

        public static List<UserAccountEO> SelectAll()
        {
            List<UserAccountEO> userAccounts = new List<UserAccountEO>();

            List<UserAccount> userAccountDTOs = UserAccountsData.SelectAll();

            foreach (UserAccount userAccountDTO in userAccountDTOs)
            {
                UserAccountEO userAccountEO = new UserAccountEO();
                userAccountEO.MapData(userAccountDTO);
                userAccounts.Add(userAccountEO);
            }

            return userAccounts;
        }
    }
}
